@@ -19,55 +19,68 @@
 #
 import logging
 
-import dlg.droputils
-
 from dlg.drop import BarrierAppDROP
 from dlg.meta import dlg_batch_input, dlg_batch_output, dlg_component, dlg_streaming_input, dlg_string_param, dlg_int_param
 import casacore.tables
 
+try:
+    from dlg.droputils import save_npy, load_npy
+except ImportError:
+    from dlg.droputils import save_numpy as save_npy, load_numpy as load_npy
+
 logger = logging.getLogger(__name__)
 
 
 ##
-# @brief MSQueryApp
+# @brief TaqlQueryApp
 # @details Queries a single measurement set table column to a .npy drop
 # @par EAGLE_START
 # @param category PythonApp
-# @param[in] cparam/appclass Application class/dlg_casacore_components.taql.MSQueryApp/String/readonly/
+# @param[in] cparam/appclass Application class/dlg_casacore_components.taql.TaqlQueryApp/String/readonly/False//False/
 #     \~English Application class
-# @param[in] aparam/column Column//String/readwrite/False//False/
+# @param[in] cparam/execution_time Execution Time/5/Float/readonly/False//False/
+#     \~English Estimated execution time
+# @param[in] cparam/num_cpus No. of CPUs/1/Integer/readonly/False//False/
+#     \~English Number of cores used
+# @param[in] cparam/group_start Group start/False/Boolean/readwrite/False//False/
+#     \~English Is this node the start of a group?
+# @param[in] cparam/input_error_threshold "Input error rate (%)"/0/Integer/readwrite/False//False/
+#     \~English the allowed failure rate of the inputs (in percent), before this component goes to ERROR state and is not executed
+# @param[in] cparam/n_tries Number of tries/1/Integer/readwrite/False//False/
+#     \~English Specifies the number of times the 'run' method will be executed before finally giving up
+# @param[in] cparam/column Column//String/readwrite/False//False/
 #     \~English Column expression
-# @param[in] aparam/where Where//String/readwrite/False//False/
+# @param[in] cparam/where Where//String/readwrite/False//False/
 #     \~English Where expression
-# @param[in] aparam/orderby OrderBy//String/readwrite/False//False/
+# @param[in] cparam/orderby OrderBy//String/readwrite/False//False/
 #     \~English OrderBy expression
-# @param[in] aparam/offset Offset//Integer/readwrite/False//False/
+# @param[in] cparam/offset Offset//Integer/readwrite/False//False/
 #     \~English Offset expression
-# @param[in] aparam/limit Limit//Integer/readwrite/False//False/
+# @param[in] cparam/limit Limit//Integer/readwrite/False//False/
 #     \~English Limit expression
 # @param[in] port/ms MS/PathBasedDrop
 #     \~English MS input path
 # @param[out] port/array Array/npy/
 #     \~English npy output
 # @par EAGLE_END
-class MSQueryApp(BarrierAppDROP):
+class TaqlQueryApp(BarrierAppDROP):
     component_meta = dlg_component(
-        "MSQueryApp",
-        "MS Query App",
+        "TaqlQueryApp",
+        "Taql Query App",
         [dlg_batch_input("binary/*", [])],
         [dlg_batch_output("binary/*", [])],
         [dlg_streaming_input("binary/*")],
     )
-    column: str = dlg_string_param("column", None)
-    where: str = dlg_string_param("where", None)
-    orderby: str = dlg_string_param("orderby", None)
-    offset: int = dlg_int_param("offset", None)
-    limit: int = dlg_int_param("limit", None)
+    column: str = dlg_string_param("column", None)  # type: ignore
+    where: str = dlg_string_param("where", None)  # type: ignore
+    orderby: str = dlg_string_param("orderby", None)  # type: ignore
+    offset: int = dlg_int_param("offset", None)  # type: ignore
+    limit: int = dlg_int_param("limit", None)  # type: ignore
 
     def run(self):
         db = casacore.tables.table(self.inputs[0].path)
         if len(self.inputs) > 1:
-            indexes = dlg.droputils.load_numpy(self.inputs[1])
+            indexes = load_npy(self.inputs[1])
             self.offset = indexes[0]
             self.limit = indexes[-1]
         data = db.query(
@@ -78,7 +91,7 @@ class MSQueryApp(BarrierAppDROP):
             offset=self.offset,
         ).getcol("OUTPUT")
         for drop in self.outputs:
-            dlg.droputils.save_numpy(drop, data)
+            save_npy(drop, data)
 
 
 ##
@@ -86,9 +99,19 @@ class MSQueryApp(BarrierAppDROP):
 # @details Queries a single measurement set table column to a .npy drop
 # @par EAGLE_START
 # @param category PythonApp
-# @param[in] param/appclass Application class/dlg_casacore_components.taql.TaqlColApp/String/readonly/
+# @param[in] cparam/appclass Application class/dlg_casacore_components.taql.TaqlColApp/String/readonly/False//False/
 #     \~English Application class
-# @param[in] aparam/query Query//String/readwrite/False//False/
+# @param[in] cparam/execution_time Execution Time/5/Float/readonly/False//False/
+#     \~English Estimated execution time
+# @param[in] cparam/num_cpus No. of CPUs/1/Integer/readonly/False//False/
+#     \~English Number of cores used
+# @param[in] cparam/group_start Group start/False/Boolean/readwrite/False//False/
+#     \~English Is this node the start of a group?
+# @param[in] cparam/input_error_threshold "Input error rate (%)"/0/Integer/readwrite/False//False/
+#     \~English the allowed failure rate of the inputs (in percent), before this component goes to ERROR state and is not executed
+# @param[in] cparam/n_tries Number of tries/1/Integer/readwrite/False//False/
+#     \~English Specifies the number of times the 'run' method will be executed before finally giving up
+# @param[in] cparam/query Query//String/readwrite/False//False/
 #     \~English Query expression using table variable '$1'
 # @param[in] port/ms MS/PathBasedDrop
 #     \~English MS input path
@@ -103,7 +126,7 @@ class TaqlColApp(BarrierAppDROP):
         [dlg_batch_output("binary/*", [])],
         [dlg_streaming_input("binary/*")],
     )
-    query: str = dlg_string_param("query", None)
+    query: str = dlg_string_param("query", None)  # type: ignore
 
     def run(self):
         db = casacore.tables.table(self.inputs[0].path)
@@ -111,7 +134,7 @@ class TaqlColApp(BarrierAppDROP):
         assert len(query.colnames()) == 1
         for drop in self.outputs:
             data = query.getcol(query.colnames()[0])
-            dlg.droputils.save_numpy(drop, data)
+            save_npy(drop, data)
 
         # df = pandas.DataFrame.from_records()
         # self.outputs[0].sav
